@@ -40,10 +40,11 @@ def _move_to_this_dir():
 
 if __name__ == '__main__':
     inp = sys.argv[1]
-    
+    print('input is', inp)
     # fix a windows issue not removing the single qoute ...
     if inp[0] == "'":
         inp = inp[1:-1]
+        print('trimmed input to', inp)
 
     env_data = json.loads(inp)
     create_app_with_resource(env_data)
